# <a id="about-icinga2"></a> About icinga2apic

icinga2apic is a [Python](http://www.python.org) module to interact with the [Icinga 2 RESTful API](http://docs.icinga.org/icinga2/latest/doc/module/icinga2/chapter/icinga2-api).

## <a id="features"></a> Features

1. [basic and certificate auth](2-authentication.md)
1. [config file support](2-authentication.md#-config-file)
1. [objects (zone support)](3-objects.md)
1. [actions](4-actions.md)
1. [events](5-events.md)
1. [status](6-status.md)

## <a id="development-info"></a> Development

The code is based on [fmnisme's version](https://github.com/fmnisme/python-icinga2api). Forking, reporting bugs and sending PRs is very appreciated.
